@@ -27,8 +27,8 @@
 
 #include <QMimeData>
 
-#include <KDebug>
-#include <KIcon>
+#include <QDebug>
+#include <QIcon>
 
 
 static KHotKeys::ActionDataBase *findElement(
@@ -201,7 +201,7 @@ QVariant KHotkeysModel::data( const QModelIndex &index, int role ) const
             // regardless of the content it has
             case 0:
                 return dynamic_cast<KHotKeys::ActionDataGroup*>(action)
-                    ? KIcon("folder")
+                    ? QIcon::fromTheme("folder")
                     : QVariant();
 
             default:
@@ -256,7 +256,7 @@ bool KHotkeysModel::dropMimeData(
     if ( (action!=Qt::CopyAction)
             || !data->hasFormat("application/x-pointer"))
         {
-        kDebug() << "Drop not supported " << data->formats();
+        qDebug() << "Drop not supported " << data->formats();
         return false;
         }
 
@@ -426,7 +426,7 @@ void KHotkeysModel::importInputActions(const QModelIndex &index, KConfigBase con
 
     if (settings()->importFrom(group, config, KHotKeys::ImportAsk, KHotKeys::Retain))
         {
-        kDebug();
+        qDebug();
         reset();
         save();
         }
@@ -525,7 +525,7 @@ bool KHotkeysModel::moveElement(
     do  {
         if (tmp == element)
             {
-            kDebug() << "Forbidden move" << tmp->name();
+            qDebug() << "Forbidden move" << tmp->name();
             return false;
             }
         }
